# [Zope-tests] OK : Zope 3.4 KGS / Python2.4.6 64bit linux

ccomb at free.fr ccomb at free.fr
Thu Feb 3 00:23:58 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.6 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.13_win-py2.6 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope 3.4 KGS / Python2.4.6 64bit linux
    Build: http://buildbot.afpy.org/kgs3.4/builders/Python2.4.6%2064bit%20linux/builds/156

    Build Reason: The Nightly scheduler named 'nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://buildbot.afpy.org/kgs3.4/

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.6 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.13_win-py2.6 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list